import { A as API_PATH } from './constants-9cfa4d7b.js';
import 'path';
import 'url';

/*! (c) 2020 Andrea Giammarchi */

const {parse: $parse, stringify: $stringify} = JSON;

const Primitive = String;   // it could be Number
const primitive = 'string'; // it could be 'number'
const object = 'object';

const noop = (_, value) => value;

const set = (known, input, value) => {
  const index = Primitive(input.push(value) - 1);
  known.set(value, index);
  return index;
};

const stringify = (value, replacer, space) => {
  const $ = replacer && typeof replacer === object ?
            (k, v) => (k === '' || -1 < replacer.indexOf(k) ? v : void 0) :
            (replacer || noop);
  const known = new Map;
  const input = [];
  const output = [];
  let i = +set(known, input, $.call({'': value}, '', value));
  let firstRun = !i;
  while (i < input.length) {
    firstRun = true;
    output[i] = $stringify(input[i++], replace, space);
  }
  return '[' + output.join(',') + ']';
  function replace(key, value) {
    if (firstRun) {
      firstRun = !firstRun;
      return value;
    }
    const after = $.call(this, key, value);
    switch (typeof after) {
      case object:
        if (after === null) return after;
      case primitive:
        return known.get(after) || set(known, input, after);
    }
    return after;
  }
};

function sendFlatted(res, data) {
  res.setHeader("Content-Type", "application/json");
  res.write(stringify(data));
  res.statusCode = 200;
  res.end();
}
function middlewareAPI(ctx) {
  return (req, res, next) => {
    var _a;
    if (!((_a = req.url) == null ? void 0 : _a.startsWith(API_PATH)))
      return next();
    const url = req.url.slice(API_PATH.length);
    if (url === "/") {
      return sendFlatted(res, {
        files: ctx.state.filesMap
      });
    }
    if (url === "/files") {
      return sendFlatted(res, {
        files: Object.keys(ctx.state.filesMap)
      });
    }
    res.statusCode = 404;
    res.end();
  };
}

export { middlewareAPI as default, sendFlatted };
