import { n as nanoid } from './index-9e71c815.js';

const context = {
  tasks: [],
  currentSuite: null
};
function collectTask(task) {
  var _a;
  (_a = context.currentSuite) == null ? void 0 : _a.tasks.push(task);
}
async function runWithSuite(suite, fn) {
  const prev = context.currentSuite;
  context.currentSuite = suite;
  await fn();
  context.currentSuite = prev;
}
function getDefaultTestTimeout() {
  var _a, _b;
  return ((_b = (_a = process.__vitest_worker__) == null ? void 0 : _a.config) == null ? void 0 : _b.testTimeout) ?? 5e3;
}
function getDefaultHookTimeout() {
  var _a, _b;
  return ((_b = (_a = process.__vitest_worker__) == null ? void 0 : _a.config) == null ? void 0 : _b.hookTimeout) ?? 5e3;
}
function withTimeout(fn, _timeout) {
  const timeout = _timeout ?? getDefaultTestTimeout();
  if (timeout <= 0 || timeout === Infinity)
    return fn;
  return (...args) => {
    return Promise.race([fn(...args), new Promise((resolve, reject) => {
      const timer = setTimeout(() => {
        clearTimeout(timer);
        reject(new Error(`Test timed out in ${timeout}ms.`));
      }, timeout);
      timer.unref();
    })]);
  };
}
function ensureAsyncTest(fn) {
  if (!fn.length)
    return fn;
  return () => new Promise((resolve, reject) => {
    const done = (...args) => args[0] ? reject(args[0]) : resolve();
    fn(done);
  });
}
function normalizeTest(fn, timeout) {
  return withTimeout(ensureAsyncTest(fn), timeout);
}

const fnMap = /* @__PURE__ */ new WeakMap();
const hooksMap = /* @__PURE__ */ new WeakMap();
function setFn(key, fn) {
  fnMap.set(key, fn);
}
function getFn(key) {
  return fnMap.get(key);
}
function setHooks(key, hooks) {
  hooksMap.set(key, hooks);
}
function getHooks(key) {
  return hooksMap.get(key);
}

const suite = createSuite();
const defaultSuite = suite("");
function clearContext() {
  context.tasks.length = 0;
  defaultSuite.clear();
  context.currentSuite = defaultSuite;
}
function getCurrentSuite() {
  return context.currentSuite || defaultSuite;
}
function createSuiteHooks() {
  return {
    beforeAll: [],
    afterAll: [],
    beforeEach: [],
    afterEach: []
  };
}
function createSuiteCollector(name, factory = () => {
}, mode, suiteComputeMode) {
  const tasks = [];
  const factoryQueue = [];
  let suite2;
  initSuite();
  const test2 = createTestCollector((name2, fn, mode2, computeMode) => {
    const test3 = {
      id: nanoid(),
      type: "test",
      name: name2,
      mode: mode2,
      computeMode: computeMode ?? (suiteComputeMode ?? "serial"),
      suite: void 0
    };
    setFn(test3, fn);
    tasks.push(test3);
  });
  const collector = {
    type: "collector",
    name,
    mode,
    test: test2,
    tasks,
    collect,
    clear,
    on: addHook
  };
  function addHook(name2, ...fn) {
    getHooks(suite2)[name2].push(...fn);
  }
  function initSuite() {
    suite2 = {
      id: nanoid(),
      type: "suite",
      computeMode: "serial",
      name,
      mode,
      tasks: []
    };
    setHooks(suite2, createSuiteHooks());
  }
  function clear() {
    tasks.length = 0;
    factoryQueue.length = 0;
    initSuite();
  }
  async function collect(file) {
    factoryQueue.length = 0;
    if (factory)
      await runWithSuite(collector, () => factory(test2));
    const allChildren = await Promise.all([...factoryQueue, ...tasks].map((i) => i.type === "collector" ? i.collect(file) : i));
    suite2.file = file;
    suite2.tasks = allChildren;
    allChildren.forEach((task) => {
      task.suite = suite2;
      if (file)
        task.file = file;
    });
    return suite2;
  }
  collectTask(collector);
  return collector;
}
function createTestCollector(collectTest) {
  function test2(name, fn, timeout) {
    collectTest(name, normalizeTest(fn, timeout), "run");
  }
  test2.concurrent = concurrent;
  test2.skip = skip;
  test2.only = only;
  test2.todo = todo;
  function concurrent(name, fn, timeout) {
    collectTest(name, normalizeTest(fn, timeout), "run", "concurrent");
  }
  concurrent.skip = (name, fn, timeout) => collectTest(name, normalizeTest(fn, timeout), "skip", "concurrent");
  concurrent.only = (name, fn, timeout) => collectTest(name, normalizeTest(fn, timeout), "only", "concurrent");
  concurrent.todo = todo;
  function skip(name, fn, timeout) {
    collectTest(name, normalizeTest(fn, timeout), "skip");
  }
  skip.concurrent = concurrent.skip;
  function only(name, fn, timeout) {
    collectTest(name, normalizeTest(fn, timeout), "only");
  }
  only.concurrent = concurrent.only;
  function todo(name) {
    collectTest(name, () => {
    }, "todo");
  }
  todo.concurrent = todo;
  return test2;
}
const test = function() {
  function test2(name, fn, timeout) {
    return getCurrentSuite().test(name, fn, timeout);
  }
  function concurrent(name, fn, timeout) {
    return getCurrentSuite().test.concurrent(name, fn, timeout);
  }
  concurrent.skip = (name, fn, timeout) => getCurrentSuite().test.concurrent.skip(name, fn, timeout);
  concurrent.only = (name, fn, timeout) => getCurrentSuite().test.concurrent.only(name, fn, timeout);
  concurrent.todo = (name) => getCurrentSuite().test.concurrent.todo(name);
  function skip(name, fn, timeout) {
    return getCurrentSuite().test.skip(name, fn, timeout);
  }
  skip.concurrent = (name, fn, timeout) => getCurrentSuite().test.skip.concurrent(name, fn, timeout);
  function only(name, fn, timeout) {
    return getCurrentSuite().test.only(name, fn, timeout);
  }
  only.concurrent = (name, fn, timeout) => getCurrentSuite().test.only.concurrent(name, fn, timeout);
  function todo(name) {
    return getCurrentSuite().test.todo(name);
  }
  todo.concurrent = (name) => getCurrentSuite().test.todo.concurrent(name);
  test2.concurrent = concurrent;
  test2.skip = skip;
  test2.only = only;
  test2.todo = todo;
  return test2;
}();
function createSuite() {
  function suite2(suiteName, factory) {
    return createSuiteCollector(suiteName, factory, "run");
  }
  function concurrent(suiteName, factory) {
    return createSuiteCollector(suiteName, factory, "run", "concurrent");
  }
  concurrent.skip = (suiteName, factory) => createSuiteCollector(suiteName, factory, "skip", "concurrent");
  concurrent.only = (suiteName, factory) => createSuiteCollector(suiteName, factory, "only", "concurrent");
  concurrent.todo = (suiteName) => createSuiteCollector(suiteName, void 0, "todo");
  function skip(suiteName, factory) {
    return createSuiteCollector(suiteName, factory, "skip");
  }
  skip.concurrent = concurrent.skip;
  function only(suiteName, factory) {
    return createSuiteCollector(suiteName, factory, "only");
  }
  only.concurrent = concurrent.only;
  function todo(suiteName) {
    return createSuiteCollector(suiteName, void 0, "todo");
  }
  todo.concurrent = concurrent.todo;
  suite2.concurrent = concurrent;
  suite2.skip = skip;
  suite2.only = only;
  suite2.todo = todo;
  return suite2;
}
const describe = suite;
const it = test;

export { getDefaultHookTimeout as a, setHooks as b, createSuiteHooks as c, describe as d, clearContext as e, defaultSuite as f, getCurrentSuite as g, context as h, it as i, getHooks as j, getFn as k, suite as s, test as t, withTimeout as w };
